AES_DIGEST

Struct AES_DIGEST 

pub struct AES_DIGEST { /* private fields */ }

Methods from Deref<Target = Cipher>

pub fn nid(&self) -> Nid

Returns the cipher’s Nid.

This corresponds to EVP_CIPHER_nid.

pub fn as_ptr(&self) -> *const EVP_CIPHER

pub fn key_len(&self) -> usize

Returns the length of keys used with this cipher.

pub fn iv_len(&self) -> Option<usize>

Returns the length of the IV used with this cipher, or None if the cipher does not use an IV.

pub fn block_size(&self) -> usize

Returns the block size of the cipher.

Note

Stream ciphers such as RC4 have a block size of 1.